### Name: spower
### Title: Simulate Power of 2-Sample Test for Survival under Complex
###   Conditions
### Aliases: spower Quantile2 print.Quantile2 plot.Quantile2 logrank
###   Gompertz2 Lognorm2 Weibull2
### Keywords: htest survival

### ** Examples

# Simulate a simple 2-arm clinical trial with exponential survival so
# we can compare power simulations of logrank-Cox test with cpower()
# Hazard ratio is constant and patients enter the study uniformly
# with follow-up ranging from 1 to 3 years
# Drop-in probability is constant at .1 and drop-out probability is
# constant at .175.  Two-year survival of control patients in absence
# of drop-in is .8 (mortality=.2).  Note that hazard rate is -log(.8)/2
# Total sample size (both groups combined) is 1000
# % mortality reduction by intervention (if no dropin or dropout) is 25
# This corresponds to a hazard ratio of 0.7283 (computed by cpower)

cpower(2, 1000, .2, 25, accrual=2, tmin=1, 
       noncomp.c=10, noncomp.i=17.5)

ranfun <- Quantile2(function(x)exp(log(.8)/2*x),
                    hratio=function(x)0.7283156,
                    dropin=function(x).1,
                    dropout=function(x).175)

rcontrol <- function(n) ranfun(n, what='control')
rinterv  <- function(n) ranfun(n, what='int')
rcens    <- function(n) runif(n, 1, 3)

set.seed(11)   # So can reproduce results
spower(rcontrol, rinterv, rcens, nc=500, ni=500, 
       test=logrank, nsim=50)  # normally use nsim=500 or 1000

# Simulate a 2-arm 5-year follow-up study for which the control group's
# survival distribution is Weibull with 1-year survival of .95 and
# 3-year survival of .7.  All subjects are followed at least one year,
# and patients enter the study with linearly increasing probability  after that
# Assume there is no chance of dropin for the first 6 months, then the
# probability increases linearly up to .15 at 5 years
# Assume there is a linearly increasing chance of dropout up to .3 at 5 years
# Assume that the treatment has no effect for the first 9 months, then
# it has a constant effect (hazard ratio of .75)

# First find the right Weibull distribution for compliant control patients
sc <- Weibull2(c(1,3), c(.95,.7))
sc

# Inverse cumulative distribution for case where all subjects are followed
# at least a years and then between a and b years the density rises
# as (time - a) ^ d is a + (b-a) * u ^ (1/(d+1))

rcens <- function(n) 1 + (5-1) * (runif(n) ^ .5)
# To check this, type hist(rcens(10000), nclass=50)

# Put it all together

f <- Quantile2(sc, 
      hratio=function(x)ifelse(x<=.75, 1, .75),
      dropin=function(x)ifelse(x<=.5, 0, .15*(x-.5)/(5-.5)),
      dropout=function(x).3*x/5)

par(mfrow=c(2,2))
# par(mfrow=c(1,1)) to make legends fit
plot(f, 'all', label.curves=list(keys='lines'))

rcontrol <- function(n) f(n, 'control')
rinterv  <- function(n) f(n, 'intervention')

set.seed(211)
spower(rcontrol, rinterv, rcens, nc=350, ni=350, 
       test=logrank, nsim=50)  # normally nsim=500 or more
par(mfrow=c(1,1))

## Not run: 
##D # Do an unstratified logrank test
##D library(survival)
##D # From SAS/STAT PROC LIFETEST manual, p. 1801
##D days <- c(179,256,262,256,255,224,225,287,319,264,237,156,270,257,242,
##D           157,249,180,226,268,378,355,319,256,171,325,325,217,255,256,
##D           291,323,253,206,206,237,211,229,234,209)
##D status <- c(1,1,1,1,1,0,1,1,1,1,0,1,1,1,1,1,1,1,1,0,
##D             0,rep(1,19))
##D treatment <- c(rep(1,10), rep(2,10), rep(1,10), rep(2,10))
##D sex <- Cs(F,F,M,F,M,F,F,M,M,M,F,F,M,M,M,F,M,F,F,M,
##D           M,M,M,M,F,M,M,F,F,F,M,M,M,F,F,M,F,F,F,F)
##D data.frame(days, status, treatment, sex)
##D table(treatment, status)
##D logrank(Surv(days, status), treatment)  # agrees with p. 1807
##D # For stratified tests the picture is puzzling.
##D # survdiff(Surv(days,status) ~ treatment + strata(sex))$chisq
##D # is 7.246562, which does not agree with SAS (7.1609)
##D # But summary(coxph(Surv(days,status) ~ treatment + strata(sex)))
##D # yields 7.16 whereas summary(coxph(Surv(days,status) ~ treatment))
##D # yields 5.21 as the score test, not agreeing with SAS or logrank() (5.6485)
## End(Not run)



